(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     32676,        844]
NotebookOptionsPosition[     33027,        833]
NotebookOutlinePosition[     33492,        853]
CellTagsIndexPosition[     33449,        850]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Moving a Force to a Point\n",
 StyleBox["Zhelong He, Marek-Jerzy Pindera \nUniversity of Virginia, \
2017-09-18",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell[TextData[{
 "Sometimes it is convenient to reduce a system of forces and couple moments \
acting on a body to a simpler form by replacing it with an equivalent system, \
consisting of a single resultant force acting at a specific point and a \
resultant couple moment. A system is equivalent if the external effects it \
produces on a body are the same as those caused by the original force and \
couple moment system. In this context, the external effects of a system refer \
to the translating and rotating motion of the body if the body is free to \
move, or it refers to the reactive forces at the supports if the body is held \
fixed.\nThe key point of such reduction is how to move a force to a given \
point equivalently. The following case shows the procedure of such moving. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], "A"], TraditionalForm]]],
 " is applied at point A, and we want to move it to point B without \
disturbing the overall equilibrium. So, we add two forces at point A, they \
are both parallel with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], "A"], TraditionalForm]]],
 " and have the same magnitude of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], "A"], TraditionalForm]]],
 ", but one has same direction as ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], "A"], TraditionalForm]]],
 " and the other has opposite direction as ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], "A"], TraditionalForm]]],
 ". Here, we denote them as ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], 
    RowBox[{"B", "+"}]], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], 
    RowBox[{"B", "-"}]], TraditionalForm]]],
 " separately. Now, since ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], "A"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], 
    RowBox[{"B", "-"}]], TraditionalForm]]],
 " make up a couple moment ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["M", "\[RightVector]"], TraditionalForm]]],
 ", they can be replaced with ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["M", "\[RightVector]"], TraditionalForm]]],
 ". Thus, the system can be replaced by a force acting at B which is ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], 
    RowBox[{"B", "+"}]], TraditionalForm]]],
 ", together with a couple moment ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["M", "\[RightVector]"], TraditionalForm]]],
 " which is a free vector. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], 
    RowBox[{"B", "+"}]], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["M", "\[RightVector]"], TraditionalForm]]],
 " are determined by "
}], "Text"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     OverscriptBox["F", "\[RightVector]"], 
     RowBox[{"B", "+"}]], " ", "=", " ", 
    SubscriptBox[
     OverscriptBox["F", "\[RightVector]"], "A"]}], TraditionalForm]]],
 ",   ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["M", "\[RightVector]"], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["r", "\[RightVector]"], "A"], "-", 
       SubscriptBox[
        OverscriptBox["r", "\[RightVector]"], "B"]}], ")"}], "\[Times]", 
     SubscriptBox[
      OverscriptBox["F", "\[RightVector]"], "A"]}]}], TraditionalForm]]]
}], "Text",
 TextAlignment->Center],

Cell["\<\
By doing this, we can move a force to any given point without disturbing the \
overall equilibrium since the total force and the total moment produced by \
the force about any point remain the same. Suppose we have several forces \
acting on several points, we can use same process to move these forces to an \
given point equivalently, and then get one resultant force and one resultant \
couple moment for all the forces acting at this point as well as those couple \
moments, thus simplifying the system.\
\>", "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`fax$$ = 0, $CellContext`fay$$ = 
    0, $CellContext`faz$$ = 0, $CellContext`opa0$$ = 1, $CellContext`rax$$ = 
    0, $CellContext`ray$$ = 0, $CellContext`raz$$ = 0, $CellContext`rbx$$ = 
    0, $CellContext`rby$$ = 0, $CellContext`rbz$$ = 
    0, $CellContext`replace$$ = False, $CellContext`showforce$$ = 
    False, $CellContext`size$$ = 2, $CellContext`step$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`size$$], 2, 
       Text[
        Style["Plot Range", 12]]}, {1, 2, 4, 8}}, {{
       Hold[$CellContext`opa0$$], 1, 
       Text[
        Style["Coordinate Visibility", 12]]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`step$$], 1, ""}, {1 -> Row[{
          Text[
           Style["Step", 12]], 
          Spacer[2], 
          Text[
           Style["1", 12]]}], 2 -> Row[{
          Text[
           Style["Step", 12]], 
          Spacer[2], 
          Text[
           Style["2", 12]]}], 3 -> Row[{
          Text[
           Style["Step", 12]], 
          Spacer[2], 
          Text[
           Style["3", 12]]}], 4 -> Row[{
          Text[
           Style["Step", 12]], 
          Spacer[2], 
          Text[
           Style["4", 12]]}]}}, {{
       Hold[$CellContext`rax$$], 0, 
       Row[{
         Text[
          Style[
           Subscript[$CellContext`r, $CellContext`Ax], 12, Italic]], 
         Spacer[2.5]}]}, 
      Dynamic[-$CellContext`size$$], 
      Dynamic[$CellContext`size$$]}, {{
       Hold[$CellContext`ray$$], 0, 
       Row[{
         Text[
          Style[
           Subscript[$CellContext`r, $CellContext`Ay], 12, Italic]]}]}, 
      Dynamic[-$CellContext`size$$], 
      Dynamic[$CellContext`size$$]}, {{
       Hold[$CellContext`raz$$], 0, 
       Row[{
         Text[
          Style[
           Subscript[$CellContext`r, $CellContext`Az], 12, Italic]], 
         Spacer[2.]}]}, 
      Dynamic[-$CellContext`size$$], 
      Dynamic[$CellContext`size$$]}, {{
       Hold[$CellContext`fax$$], 0, 
       Row[{
         Text[
          Style[
           Subscript[$CellContext`F, $CellContext`Ax], 12, Italic]]}]}, 
      Dynamic[-$CellContext`size$$], 
      Dynamic[$CellContext`size$$]}, {{
       Hold[$CellContext`fay$$], 0, 
       Row[{
         Text[
          Style[
           Subscript[$CellContext`F, $CellContext`Ay], 12, Italic]]}]}, 
      Dynamic[-$CellContext`size$$], 
      Dynamic[$CellContext`size$$]}, {{
       Hold[$CellContext`faz$$], 0, 
       Row[{
         Text[
          Style[
           Subscript[$CellContext`F, $CellContext`Az], 12, Italic]]}]}, 
      Dynamic[-$CellContext`size$$], 
      Dynamic[$CellContext`size$$]}, {{
       Hold[$CellContext`rbx$$], 0, 
       Row[{
         Text[
          Style[
           Subscript[$CellContext`r, $CellContext`Bx], 12, Italic]], 
         Spacer[0.5]}]}, 
      Dynamic[-$CellContext`size$$], 
      Dynamic[$CellContext`size$$]}, {{
       Hold[$CellContext`rby$$], 0, 
       Row[{
         Text[
          Style[
           Subscript[$CellContext`r, $CellContext`By], 12, Italic]], 
         Spacer[2.]}]}, 
      Dynamic[-$CellContext`size$$], 
      Dynamic[$CellContext`size$$]}, {{
       Hold[$CellContext`rbz$$], 0, 
       Row[{
         Text[
          Style[
           Subscript[$CellContext`r, $CellContext`Bz], 12, Italic]], 
         Spacer[1.]}]}, 
      Dynamic[-$CellContext`size$$], 
      Dynamic[$CellContext`size$$]}, {{
       Hold[$CellContext`showforce$$], False, 
       Row[{
         Text[
          Style["Add two forces at B parallel with", 12]], 
         Spacer[3], 
         Text[
          Style[
           Subscript[$CellContext`F, $CellContext`A], 12]], 
         Spacer[3], 
         Text[
          Style["and with same magnitude", 12]], 
         Spacer[50], 
         Text[
          Style["Add", 12]]}]}, {True, False}}, {{
       Hold[$CellContext`replace$$], False, 
       Row[{
         Text[
          Style["Replace two forces with red color as couple moment", 12]], 
         Spacer[50], 
         Text[
          Style["Replace", 12]]}]}, {True, False}}, {
      Hold[
       Grid[{{
          Row[{
            Manipulate`Place[1], 
            Spacer[77], 
            Manipulate`Place[2]}]}, {
          Row[{
            Manipulate`Place[3]}]}, {
          PaneSelector[{1 -> Column[{
               Row[{
                 Row[{
                   Text[
                    Style[
                    Subscript[$CellContext`F, $CellContext`A], 12]], 
                   Spacer[3], 
                   Text[
                    Style["location :", 12]], 
                   Spacer[45]}], 
                 Manipulate`Place[4], 
                 Spacer[5.], 
                 Manipulate`Place[5], 
                 Spacer[6.], 
                 Manipulate`Place[6]}], 
               Row[{
                 Row[{
                   Text[
                    Style[
                    Subscript[$CellContext`F, $CellContext`A], 12]], 
                   Spacer[3], 
                   Text[
                    Style["specification :", 12]], 
                   Spacer[20]}], 
                 Manipulate`Place[7], 
                 Spacer[2.5], 
                 Manipulate`Place[8], 
                 Spacer[4.], 
                 Manipulate`Place[9]}]}], 2 -> Row[{
               Text[
                Style["B", 12]], 
               Spacer[3], 
               Text[
                Style["location :", 12]], 
               Spacer[49], 
               Manipulate`Place[10], 
               Spacer[5.5], 
               Manipulate`Place[11], 
               Spacer[6.], 
               Manipulate`Place[12]}], 3 -> Manipulate`Place[13], 4 -> Column[{
               Manipulate`Place[14], 
               Dynamic[
                If[$CellContext`replace$$, $CellContext`temp1 = Row[{
                    Text[
                    Style["M = ", 12, Italic]], 
                    Text[
                    Style["[", 12, Italic]], 
                    Spacer[3], 
                    Text[
                    Style[
                    Dynamic[
                    NumberForm[
                    Part[
                    
                    Cross[{$CellContext`rax$$, $CellContext`ray$$, \
$CellContext`raz$$} - {$CellContext`rbx$$, $CellContext`rby$$, \
$CellContext`rbz$$}, {$CellContext`fax$$, $CellContext`fay$$, \
$CellContext`faz$$}], 1], {3, 2}]], 12, Italic]], 
                    Spacer[6], 
                    Text[
                    Style[
                    Dynamic[
                    NumberForm[
                    Part[
                    
                    Cross[{$CellContext`rax$$, $CellContext`ray$$, \
$CellContext`raz$$} - {$CellContext`rbx$$, $CellContext`rby$$, \
$CellContext`rbz$$}, {$CellContext`fax$$, $CellContext`fay$$, \
$CellContext`faz$$}], 2], {3, 2}]], 12, Italic]], 
                    Spacer[6], 
                    Text[
                    Style[
                    Dynamic[
                    NumberForm[
                    Part[
                    
                    Cross[{$CellContext`rax$$, $CellContext`ray$$, \
$CellContext`raz$$} - {$CellContext`rbx$$, $CellContext`rby$$, \
$CellContext`rbz$$}, {$CellContext`fax$$, $CellContext`fay$$, \
$CellContext`faz$$}], 3], {3, 2}]], 12, Italic]], 
                    Spacer[3], 
                    Text[
                    Style["]", 12, Italic]]}], 
                 Invisible[$CellContext`temp1]]]}]}, 
           Dynamic[$CellContext`step$$]]}}, Alignment -> Left, 
        Spacings -> {Automatic, 0.7}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {750., {378., 385.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`size$73492$$ = 0, $CellContext`opa0$73493$$ = 
    False, $CellContext`step$73494$$ = False, $CellContext`rax$73495$$ = 
    0, $CellContext`ray$73496$$ = 0, $CellContext`raz$73497$$ = 
    0, $CellContext`fax$73498$$ = 0, $CellContext`fay$73499$$ = 
    0, $CellContext`faz$73500$$ = 0, $CellContext`rbx$73501$$ = 
    0, $CellContext`rby$73502$$ = 0, $CellContext`rbz$73503$$ = 
    0, $CellContext`showforce$73504$$ = False, $CellContext`replace$73505$$ = 
    False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`fax$$ = 0, $CellContext`fay$$ = 
        0, $CellContext`faz$$ = 0, $CellContext`opa0$$ = 
        1, $CellContext`rax$$ = 0, $CellContext`ray$$ = 0, $CellContext`raz$$ = 
        0, $CellContext`rbx$$ = 0, $CellContext`rby$$ = 0, $CellContext`rbz$$ = 
        0, $CellContext`replace$$ = False, $CellContext`showforce$$ = 
        False, $CellContext`size$$ = 2, $CellContext`step$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`size$$, $CellContext`size$73492$$, 0], 
        Hold[$CellContext`opa0$$, $CellContext`opa0$73493$$, False], 
        Hold[$CellContext`step$$, $CellContext`step$73494$$, False], 
        Hold[$CellContext`rax$$, $CellContext`rax$73495$$, 0], 
        Hold[$CellContext`ray$$, $CellContext`ray$73496$$, 0], 
        Hold[$CellContext`raz$$, $CellContext`raz$73497$$, 0], 
        Hold[$CellContext`fax$$, $CellContext`fax$73498$$, 0], 
        Hold[$CellContext`fay$$, $CellContext`fay$73499$$, 0], 
        Hold[$CellContext`faz$$, $CellContext`faz$73500$$, 0], 
        Hold[$CellContext`rbx$$, $CellContext`rbx$73501$$, 0], 
        Hold[$CellContext`rby$$, $CellContext`rby$73502$$, 0], 
        Hold[$CellContext`rbz$$, $CellContext`rbz$73503$$, 0], 
        Hold[$CellContext`showforce$$, $CellContext`showforce$73504$$, False], 
        Hold[$CellContext`replace$$, $CellContext`replace$73505$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`dwf1$, $CellContext`dwf2$, $CellContext`dwf3$, \
$CellContext`dwf4$, $CellContext`dwf5$, $CellContext`dwf6$, \
$CellContext`dwf7$, $CellContext`dwf8$, $CellContext`dwf9$, \
$CellContext`dwf10$, $CellContext`dwf11$, $CellContext`dwf12$, \
$CellContext`dwf13$, $CellContext`dw1$, $CellContext`ra$, $CellContext`rb$, \
$CellContext`rba$, $CellContext`fa$, $CellContext`mc$, $CellContext`md$, \
$CellContext`rec$, $CellContext`pc$, $CellContext`na$, $CellContext`nb$, \
$CellContext`pts$, $CellContext`w$, $CellContext`k$}, $CellContext`ra$ = \
{$CellContext`rax$$, $CellContext`ray$$, $CellContext`raz$$}; \
$CellContext`rb$ = {$CellContext`rbx$$, $CellContext`rby$$, \
$CellContext`rbz$$}; $CellContext`fa$ = {$CellContext`fax$$, \
$CellContext`fay$$, $CellContext`faz$$}; $CellContext`rba$ = $CellContext`ra$ - \
$CellContext`rb$; $CellContext`mc$ = 
         Cross[$CellContext`rba$, $CellContext`fa$]; $CellContext`md$ = \
$CellContext`rb$ + 
          0.1 (Normalize[$CellContext`fa$] + 
            Normalize[$CellContext`mc$]); $CellContext`pc$ = $CellContext`rb$ + \
(2/3) $CellContext`mc$; $CellContext`na$ = 
         0.15 Normalize[$CellContext`rba$]; $CellContext`nb$ = 0.15 Normalize[
            
            Cross[$CellContext`mc$, $CellContext`rba$]]; $CellContext`pts$ = \
{$CellContext`pc$ - $CellContext`na$, $CellContext`pc$ - $CellContext`na$ + \
$CellContext`nb$, $CellContext`pc$ + $CellContext`na$ + $CellContext`nb$, \
$CellContext`pc$ + $CellContext`na$, $CellContext`pc$ + $CellContext`na$ - \
$CellContext`nb$, $CellContext`pc$ - $CellContext`na$ - $CellContext`nb$, \
$CellContext`pc$ - $CellContext`na$}; $CellContext`w$ = {
          1, 0.5, 0.5, 1, 0.5, 0.5, 1}; $CellContext`k$ = {
          0, 0, 0, 1/4, 1/2, 1/2, 3/4, 1, 1, 1}; $CellContext`rec$[{
            PatternTest[
             Pattern[$CellContext`A, 
              Blank[]], VectorQ], 
            PatternTest[
             Pattern[$CellContext`B, 
              Blank[]], VectorQ], 
            PatternTest[
             Pattern[$CellContext`F, 
              Blank[]], VectorQ]}] := 
         Module[{C, D}, C = ($CellContext`A + $CellContext`B)/2; 
           D = ($CellContext`A - $CellContext`B)/2; 
           Triangle[{{$CellContext`A + D, $CellContext`B - D, C + 
               2 $CellContext`F}, {$CellContext`A + D, $CellContext`B - D, C - 
               2 $CellContext`F}}]]; $CellContext`dwf1$ = {
           Opacity[$CellContext`opa0$$], Gray, 
           Thickness[0.002], 
           Arrowheads[0.02], 
           Arrow[{{-$CellContext`size$$, 0, 0}, {$CellContext`size$$, 0, 0}}], 
           Arrow[{{0, -$CellContext`size$$, 0}, {0, $CellContext`size$$, 0}}], 
           Arrow[{{0, 0, -$CellContext`size$$}, {0, 0, $CellContext`size$$}}], 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {
            1.1 $CellContext`size$$, (-0.05) $CellContext`size$$, (-0.05) \
$CellContext`size$$}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`size$$, 
             1.1 $CellContext`size$$, 0.05 $CellContext`size$$}], 
           Text[
           "\!\(\*\nStyleBox[\"z\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`size$$, (-0.05) \
$CellContext`size$$, 1.1 $CellContext`size$$}]}; $CellContext`dwf2$ = {
           Opacity[0.05], 
           RGBColor[0.2, 0.05, 0.1], 
           Sphere[{0, 0, 0}, 1. $CellContext`size$$]}; $CellContext`dwf3$ = {
           PointSize[0.01], 
           Point[{$CellContext`ra$}]}; $CellContext`dwf4$ = {
           Opacity[
            Boole[
             Not[$CellContext`replace$$]]], 
           Thickness[0.004], Red, 
           Arrowheads[0.02], 
           
           Arrow[{$CellContext`ra$, $CellContext`ra$ + $CellContext`fa$}]}; \
$CellContext`dwf5$ = {
           Opacity[
            Boole[Norm[$CellContext`ra$] != 0]], 
           Text[
            Style[
             Subscript[$CellContext`r, $CellContext`A], 12, 
             Italic], {$CellContext`rax$$, $CellContext`ray$$, \
$CellContext`raz$$} + (0.1 $CellContext`size$$) {1, 1, 
              1}]}; $CellContext`dwf6$ = {
           Opacity[
            Boole[
             
             Or[$CellContext`step$$ == 2, $CellContext`step$$ == 
              3, $CellContext`step$$ == 4]]], 
           Thickness[0.004], 
           PointSize[0.01], 
           Point[{$CellContext`rb$}]}; $CellContext`dwf7$ = {
           Opacity[
            Boole[
             And[Norm[$CellContext`rb$] != 0, 
              
              Or[$CellContext`step$$ == 2, $CellContext`step$$ == 
               3, $CellContext`step$$ == 4]]]], 
           Text[
            Style[
             Subscript[$CellContext`r, $CellContext`B], 12, 
             Italic], {$CellContext`rbx$$, $CellContext`rby$$, \
$CellContext`rbz$$} + (0.1 $CellContext`size$$) {1, 1, 
              1}]}; $CellContext`dwf8$ = {
           Opacity[
            Boole[
             And[
              
              Or[$CellContext`step$$ == 3, $CellContext`step$$ == 
               4], $CellContext`showforce$$]]], 
           Thickness[0.004], 
           Arrowheads[0.02], 
           
           Arrow[{$CellContext`rb$, $CellContext`rb$ + $CellContext`fa$}]}; \
$CellContext`dwf9$ = {
           Opacity[
            Boole[
             And[
              
              Or[$CellContext`step$$ == 3, $CellContext`step$$ == 
               4], $CellContext`showforce$$, 
              Not[$CellContext`replace$$]]]], 
           Thickness[0.004], 
           Arrowheads[0.02], Red, 
           
           Arrow[{$CellContext`rb$, $CellContext`rb$ - $CellContext`fa$}]}; \
$CellContext`dwf10$ = {
           Opacity[
            Boole[
             And[$CellContext`step$$ == 4, $CellContext`replace$$]]], 
           Thickness[0.004], Blue, 
           Arrowheads[0.02], 
           Arrow[{$CellContext`rb$, $CellContext`rb$ + $CellContext`mc$}], 
           Magenta, 
           Tube[
            
            BSplineCurve[$CellContext`pts$, SplineDegree -> 2, 
             SplineKnots -> $CellContext`k$, 
             SplineWeights -> $CellContext`w$], 0.01], Blue, 
           Text[
            Style["M", 12, Italic], $CellContext`rb$ + 
            1.15 $CellContext`mc$]}; $CellContext`dwf11$ = {
           Opacity[
            Boole[
             And[$CellContext`step$$ == 4, $CellContext`replace$$]]], Magenta, 
           
           Cone[{$CellContext`rb$ + (2/
               3) $CellContext`mc$ + $CellContext`na$, $CellContext`rb$ + (2/
               3) $CellContext`mc$ + (1/Sqrt[1^2 + 1^2]) (
               1 $CellContext`na$ + $CellContext`nb$)}, 
            0.05]}; $CellContext`dwf12$ = {
           Opacity[
            Boole[
             And[$CellContext`step$$ == 4, $CellContext`replace$$]]], 
           Thickness[0.004], 
           
           Line[{$CellContext`md$, $CellContext`rb$ + 
             0.1 Normalize[$CellContext`fa$]}], 
           
           Line[{$CellContext`md$, $CellContext`rb$ + 
             0.1 Normalize[$CellContext`mc$]}]}; $CellContext`dwf13$ = {
           Opacity[0.3 Boole[
              And[$CellContext`step$$ == 4, $CellContext`replace$$]]], 
           Darker[Green], 
           $CellContext`rec$[{$CellContext`ra$, $CellContext`rb$, \
$CellContext`fa$}]}; $CellContext`dw1$ = 
         Graphics3D[{$CellContext`dwf1$, $CellContext`dwf2$, \
$CellContext`dwf3$, $CellContext`dwf4$, $CellContext`dwf5$, \
$CellContext`dwf6$, $CellContext`dwf7$, $CellContext`dwf8$, \
$CellContext`dwf9$, $CellContext`dwf10$, $CellContext`dwf12$, 
            EdgeForm[{}], $CellContext`dwf11$, $CellContext`dwf13$}, 
           PlotRange -> 1.05 $CellContext`size$$, Boxed -> False, 
           ViewPoint -> {
            0.5 $CellContext`size$$, -$CellContext`size$$, 
             0.5 $CellContext`size$$}, ImageSize -> 500]; $CellContext`dw1$], 
      "Specifications" :> {{{$CellContext`size$$, 2, 
          Text[
           Style["Plot Range", 12]]}, {1, 2, 4, 8}, ImageSize -> Tiny, 
         ControlType -> Setter, ControlPlacement -> 
         1}, {{$CellContext`opa0$$, 1, 
          Text[
           Style["Coordinate Visibility", 12]]}, {1 -> "On", 0 -> "Off"}, 
         ControlType -> RadioButton, ControlPlacement -> 
         2}, {{$CellContext`step$$, 1, ""}, {1 -> Row[{
             Text[
              Style["Step", 12]], 
             Spacer[2], 
             Text[
              Style["1", 12]]}], 2 -> Row[{
             Text[
              Style["Step", 12]], 
             Spacer[2], 
             Text[
              Style["2", 12]]}], 3 -> Row[{
             Text[
              Style["Step", 12]], 
             Spacer[2], 
             Text[
              Style["3", 12]]}], 4 -> Row[{
             Text[
              Style["Step", 12]], 
             Spacer[2], 
             Text[
              Style["4", 12]]}]}, ControlType -> SetterBar, ControlPlacement -> 
         3}, {{$CellContext`rax$$, 0, 
          Row[{
            Text[
             Style[
              Subscript[$CellContext`r, $CellContext`Ax], 12, Italic]], 
            Spacer[2.5]}]}, 
         Dynamic[-$CellContext`size$$], 
         Dynamic[$CellContext`size$$], ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 4}, {{$CellContext`ray$$, 0, 
          Row[{
            Text[
             Style[
              Subscript[$CellContext`r, $CellContext`Ay], 12, Italic]]}]}, 
         Dynamic[-$CellContext`size$$], 
         Dynamic[$CellContext`size$$], ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 5}, {{$CellContext`raz$$, 0, 
          Row[{
            Text[
             Style[
              Subscript[$CellContext`r, $CellContext`Az], 12, Italic]], 
            Spacer[2.]}]}, 
         Dynamic[-$CellContext`size$$], 
         Dynamic[$CellContext`size$$], ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 6}, {{$CellContext`fax$$, 0, 
          Row[{
            Text[
             Style[
              Subscript[$CellContext`F, $CellContext`Ax], 12, Italic]]}]}, 
         Dynamic[-$CellContext`size$$], 
         Dynamic[$CellContext`size$$], ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 7}, {{$CellContext`fay$$, 0, 
          Row[{
            Text[
             Style[
              Subscript[$CellContext`F, $CellContext`Ay], 12, Italic]]}]}, 
         Dynamic[-$CellContext`size$$], 
         Dynamic[$CellContext`size$$], ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 8}, {{$CellContext`faz$$, 0, 
          Row[{
            Text[
             Style[
              Subscript[$CellContext`F, $CellContext`Az], 12, Italic]]}]}, 
         Dynamic[-$CellContext`size$$], 
         Dynamic[$CellContext`size$$], ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 9}, {{$CellContext`rbx$$, 0, 
          Row[{
            Text[
             Style[
              Subscript[$CellContext`r, $CellContext`Bx], 12, Italic]], 
            Spacer[0.5]}]}, 
         Dynamic[-$CellContext`size$$], 
         Dynamic[$CellContext`size$$], ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 10}, {{$CellContext`rby$$, 0, 
          Row[{
            Text[
             Style[
              Subscript[$CellContext`r, $CellContext`By], 12, Italic]], 
            Spacer[2.]}]}, 
         Dynamic[-$CellContext`size$$], 
         Dynamic[$CellContext`size$$], ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 11}, {{$CellContext`rbz$$, 0, 
          Row[{
            Text[
             Style[
              Subscript[$CellContext`r, $CellContext`Bz], 12, Italic]], 
            Spacer[1.]}]}, 
         Dynamic[-$CellContext`size$$], 
         Dynamic[$CellContext`size$$], ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 
         12}, {{$CellContext`showforce$$, False, 
          Row[{
            Text[
             Style["Add two forces at B parallel with", 12]], 
            Spacer[3], 
            Text[
             Style[
              Subscript[$CellContext`F, $CellContext`A], 12]], 
            Spacer[3], 
            Text[
             Style["and with same magnitude", 12]], 
            Spacer[50], 
            Text[
             Style["Add", 12]]}]}, {True, False}, ControlPlacement -> 
         13}, {{$CellContext`replace$$, False, 
          Row[{
            Text[
             Style["Replace two forces with red color as couple moment", 12]], 
            Spacer[50], 
            Text[
             Style["Replace", 12]]}]}, {True, False}, ControlPlacement -> 14}, 
        Grid[{{
           Row[{
             Manipulate`Place[1], 
             Spacer[77], 
             Manipulate`Place[2]}]}, {
           Row[{
             Manipulate`Place[3]}]}, {
           PaneSelector[{1 -> Column[{
                Row[{
                  Row[{
                    Text[
                    Style[
                    Subscript[$CellContext`F, $CellContext`A], 12]], 
                    Spacer[3], 
                    Text[
                    Style["location :", 12]], 
                    Spacer[45]}], 
                  Manipulate`Place[4], 
                  Spacer[5.], 
                  Manipulate`Place[5], 
                  Spacer[6.], 
                  Manipulate`Place[6]}], 
                Row[{
                  Row[{
                    Text[
                    Style[
                    Subscript[$CellContext`F, $CellContext`A], 12]], 
                    Spacer[3], 
                    Text[
                    Style["specification :", 12]], 
                    Spacer[20]}], 
                  Manipulate`Place[7], 
                  Spacer[2.5], 
                  Manipulate`Place[8], 
                  Spacer[4.], 
                  Manipulate`Place[9]}]}], 2 -> Row[{
                Text[
                 Style["B", 12]], 
                Spacer[3], 
                Text[
                 Style["location :", 12]], 
                Spacer[49], 
                Manipulate`Place[10], 
                Spacer[5.5], 
                Manipulate`Place[11], 
                Spacer[6.], 
                Manipulate`Place[12]}], 3 -> Manipulate`Place[13], 4 -> 
             Column[{
                Manipulate`Place[14], 
                Dynamic[
                 If[$CellContext`replace$$, $CellContext`temp1 = Row[{
                    Text[
                    Style["M = ", 12, Italic]], 
                    Text[
                    Style["[", 12, Italic]], 
                    Spacer[3], 
                    Text[
                    Style[
                    Dynamic[
                    NumberForm[
                    Part[
                    
                    Cross[{$CellContext`rax$$, $CellContext`ray$$, \
$CellContext`raz$$} - {$CellContext`rbx$$, $CellContext`rby$$, \
$CellContext`rbz$$}, {$CellContext`fax$$, $CellContext`fay$$, \
$CellContext`faz$$}], 1], {3, 2}]], 12, Italic]], 
                    Spacer[6], 
                    Text[
                    Style[
                    Dynamic[
                    NumberForm[
                    Part[
                    
                    Cross[{$CellContext`rax$$, $CellContext`ray$$, \
$CellContext`raz$$} - {$CellContext`rbx$$, $CellContext`rby$$, \
$CellContext`rbz$$}, {$CellContext`fax$$, $CellContext`fay$$, \
$CellContext`faz$$}], 2], {3, 2}]], 12, Italic]], 
                    Spacer[6], 
                    Text[
                    Style[
                    Dynamic[
                    NumberForm[
                    Part[
                    
                    Cross[{$CellContext`rax$$, $CellContext`ray$$, \
$CellContext`raz$$} - {$CellContext`rbx$$, $CellContext`rby$$, \
$CellContext`rbz$$}, {$CellContext`fax$$, $CellContext`fay$$, \
$CellContext`faz$$}], 3], {3, 2}]], 12, Italic]], 
                    Spacer[3], 
                    Text[
                    Style["]", 12, Italic]]}], 
                  Invisible[$CellContext`temp1]]]}]}, 
            Dynamic[$CellContext`step$$]]}}, Alignment -> Left, 
         Spacings -> {Automatic, 0.7}]}, 
      "Options" :> {ControlPlacement -> Top}, "DefaultOptions" :> {}],
     ImageSizeCache->{1061., {505., 513.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center,
 FontSize->12]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 211, 7, 230, "Title"],
Cell[1700, 44, 3080, 89, 273, "Text"],
Cell[4783, 135, 700, 24, 56, "Text"],
Cell[5486, 161, 531, 8, 102, "Text"],
Cell[6020, 171, 26991, 659, 1042, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature TwTcv0nbGXjvTD1YTjFdoY#B *)
